summaryrefslogtreecommitdiff
path: root/libs
diff options
context:
space:
mode:
authorLen Ovens <len@ovenwerks.net>2018-11-12 22:29:27 -0800
committerLen Ovens <len@ovenwerks.net>2018-11-12 22:30:32 -0800
commit9b2612f68615d1b3f80fce732e4a13f5e50ee87d (patch)
tree9a34b4e9d4b4a9f6c3b8d8f212c707e2fbd340a2 /libs
parentf27ca29d6c7e294a71c46d2e3390331aa72ad1d0 (diff)
Make foldback bus match foldback sends namewise
to avoid confusion with listener sends or monitor bus
Diffstat (limited to 'libs')
-rw-r--r--libs/ardour/ardour/presentation_info.h8
-rw-r--r--libs/ardour/ardour/stripable.h2
-rw-r--r--libs/ardour/enums.cc2
-rw-r--r--libs/ardour/presentation_info.cc2
-rw-r--r--libs/ardour/session.cc2
-rw-r--r--libs/surfaces/osc/osc.cc32
6 files changed, 24 insertions, 24 deletions
diff --git a/libs/ardour/ardour/stripable.h b/libs/ardour/ardour/stripable.h
index 4ba7532d9a..db65329ee8 100644
--- a/libs/ardour/ardour/stripable.h
+++ b/libs/ardour/ardour/stripable.h
@@ -74,7 +74,7 @@ class LIBARDOUR_API Stripable : public SessionObject,
bool is_private_route() const { return is_auditioner(); }
bool is_master() const { return _presentation_info.flags() & PresentationInfo::MasterOut; }
bool is_monitor() const { return _presentation_info.flags() & PresentationInfo::MonitorOut; }
- bool is_listenbus() const { return _presentation_info.flags() & PresentationInfo::ListenBus; }
+ bool is_foldbackbus() const { return _presentation_info.flags() & PresentationInfo::FoldbackBus; }
int set_state (XMLNode const&, int);
diff --git a/libs/ardour/enums.cc b/libs/ardour/enums.cc
index 28c59af7db..853391c3d9 100644
--- a/libs/ardour/enums.cc
+++ b/libs/ardour/enums.cc
@@ -735,7 +735,7 @@ setup_enum_writer ()
REGISTER_CLASS_ENUM (PresentationInfo, Auditioner);
REGISTER_CLASS_ENUM (PresentationInfo, Hidden);
REGISTER_CLASS_ENUM (PresentationInfo, OrderSet);
- REGISTER_CLASS_ENUM (PresentationInfo, ListenBus);
+ REGISTER_CLASS_ENUM (PresentationInfo, FoldbackBus);
REGISTER_BITS (_PresentationInfo_Flag);
REGISTER_CLASS_ENUM (MusicalMode,Dorian);
diff --git a/libs/ardour/presentation_info.cc b/libs/ardour/presentation_info.cc
index 19c5830819..1e0c99fc60 100644
--- a/libs/ardour/presentation_info.cc
+++ b/libs/ardour/presentation_info.cc
@@ -115,7 +115,7 @@ const PresentationInfo::order_t PresentationInfo::max_order = UINT32_MAX;
const PresentationInfo::Flag PresentationInfo::Bus = PresentationInfo::Flag (PresentationInfo::AudioBus|PresentationInfo::MidiBus);
const PresentationInfo::Flag PresentationInfo::Track = PresentationInfo::Flag (PresentationInfo::AudioTrack|PresentationInfo::MidiTrack);
const PresentationInfo::Flag PresentationInfo::Route = PresentationInfo::Flag (PresentationInfo::Bus|PresentationInfo::Track);
-const PresentationInfo::Flag PresentationInfo::AllRoutes = PresentationInfo::Flag (PresentationInfo::Route|PresentationInfo::MasterOut|PresentationInfo::MonitorOut|PresentationInfo::ListenBus);
+const PresentationInfo::Flag PresentationInfo::AllRoutes = PresentationInfo::Flag (PresentationInfo::Route|PresentationInfo::MasterOut|PresentationInfo::MonitorOut|PresentationInfo::FoldbackBus);
const PresentationInfo::Flag PresentationInfo::MixerRoutes = PresentationInfo::Flag (PresentationInfo::Route|PresentationInfo::MasterOut|PresentationInfo::MonitorOut);
const PresentationInfo::Flag PresentationInfo::AllStripables = PresentationInfo::Flag (PresentationInfo::AllRoutes|PresentationInfo::VCA);
const PresentationInfo::Flag PresentationInfo::MixerStripables = PresentationInfo::Flag (PresentationInfo::MixerRoutes|PresentationInfo::VCA);
diff --git a/libs/ardour/session.cc b/libs/ardour/session.cc
index 235eb1451a..ad2f04af61 100644
--- a/libs/ardour/session.cc
+++ b/libs/ardour/session.cc
@@ -3257,7 +3257,7 @@ Session::new_audio_route (int input_channels, int output_channels, RouteGroup* r
StateProtector sp (this);
if (Profile->get_trx()) {
add_routes (ret, false, false, false, order);
- } else if (flags == PresentationInfo::ListenBus) {
+ } else if (flags == PresentationInfo::FoldbackBus) {
add_routes (ret, false, false, true, order); // no autoconnect
} else {
add_routes (ret, false, true, true, order); // autoconnect // outputs only
diff --git a/libs/ardour/ardour/presentation_info.h b/libs/ardour/ardour/presentation_info.h
index 41e11d9ba8..de728138cc 100644
--- a/libs/ardour/ardour/presentation_info.h
+++ b/libs/ardour/ardour/presentation_info.h
@@ -118,18 +118,18 @@ class LIBARDOUR_API PresentationInfo : public PBD::Stateful
/* single bit indicates that the group order is set */
OrderSet = 0x400,
/* bus type for monitor mixes */
- ListenBus = 0x2000,
+ FoldbackBus = 0x2000,
/* special mask to delect out "state" bits */
StatusMask = (Hidden),
/* special mask to delect select type bits */
- TypeMask = (AudioBus|AudioTrack|MidiTrack|MidiBus|VCA|MasterOut|MonitorOut|Auditioner|ListenBus)
+ TypeMask = (AudioBus|AudioTrack|MidiTrack|MidiBus|VCA|MasterOut|MonitorOut|Auditioner|FoldbackBus)
};
static const Flag AllStripables; /* mask to use for any route or VCA (but not auditioner) */
- static const Flag MixerStripables; /* mask to use for any route or VCA (but not auditioner or Listenbus) */
+ static const Flag MixerStripables; /* mask to use for any route or VCA (but not auditioner or foldbackbus) */
static const Flag AllRoutes; /* mask to use for any route include master+monitor, but not auditioner */
- static const Flag MixerRoutes; /* mask to use for any route include master+monitor, but not auditioner or ListenBus*/
+ static const Flag MixerRoutes; /* mask to use for any route include master+monitor, but not auditioner or foldbackbus*/
static const Flag Route; /* mask for any route (bus or track */
static const Flag Track; /* mask to use for any track */
static const Flag Bus; /* mask to use for any bus */
diff --git a/libs/surfaces/osc/osc.cc b/libs/surfaces/osc/osc.cc
index 691107f538..08b8fb9c18 100644
--- a/libs/surfaces/osc/osc.cc
+++ b/libs/surfaces/osc/osc.cc
@@ -4275,7 +4275,7 @@ OSC::sel_comment (char *newcomment, lo_message msg) {
}
int
-OSC::sel_new_personal_send (char *listener, lo_message msg)
+OSC::sel_new_personal_send (char *foldback, lo_message msg)
{
OSCSurface *sur = get_surface(get_address (msg));
boost::shared_ptr<Stripable> s;
@@ -4288,24 +4288,24 @@ OSC::sel_new_personal_send (char *listener, lo_message msg)
return -1;
}
}
/* if a listenbus called listener exists use it
* other wise create create it. Then create a personal send from
* this route to that bus.
*/
- string listenbus = listener;
- string listen_name = listenbus;
- if (listenbus.find ("- monitor") == string::npos) {
- listen_name = string_compose ("%1 - monitor", listenbus);
+ string foldbackbus = foldback;
+ string foldback_name = foldbackbus;
+ if (foldbackbus.find ("- monitor") == string::npos) {
+ foldback_name = string_compose ("%1 - monitor", foldbackbus);
}
- boost::shared_ptr<Route> lsn_rt = session->route_by_name (listen_name);
+ boost::shared_ptr<Route> lsn_rt = session->route_by_name (foldback_name);
if (!lsn_rt) {
- // doesn't exist but check if raw name does and is listenbus
- boost::shared_ptr<Route> raw_rt = session->route_by_name (listenbus);
- if (raw_rt && raw_rt->is_listenbus()) {
+ // doesn't exist but check if raw name does and is foldbackbus
+ boost::shared_ptr<Route> raw_rt = session->route_by_name (foldbackbus);
+ if (raw_rt && raw_rt->is_foldbackbus()) {
lsn_rt = raw_rt;
} else {
- // create the listenbus
- RouteList list = session->new_audio_route (2, 2, 0, 1, listen_name, PresentationInfo::ListenBus, (uint32_t) -1);
+ // create the foldbackbus
+ RouteList list = session->new_audio_route (2, 2, 0, 1, foldback_name, PresentationInfo::FoldbackBus, (uint32_t) -1);
lsn_rt = *(list.begin());
lsn_rt->presentation_info().set_hidden (true);
session->set_dirty();
@@ -4329,7 +4329,7 @@ OSC::sel_new_personal_send (char *listener, lo_message msg)
PBD::warning << "OSC: new_send - can't send to self." << endmsg;
}
} else {
- PBD::warning << "OSC: new_send - no ListenBus to send to." << endmsg;
+ PBD::warning << "OSC: new_send - no FoldbackBus to send to." << endmsg;
}
return -1;
@@ -6349,7 +6349,7 @@ OSC::get_sorted_stripables(std::bitset<32> types, bool cue, uint32_t custom, Sor
sorted.push_back (s);
} else if (types[4] && boost::dynamic_pointer_cast<VCA>(s)) {
sorted.push_back (s);
- } else if (s->is_listenbus()) {
+ } else if (s->is_foldbackbus()) {
if (types[7]) {
sorted.push_back (s);
}
@@ -6570,7 +6570,7 @@ OSC::cue_new_aux (string name, string dest_1, string dest_2, lo_message msg)
RouteList list;
boost::shared_ptr<Stripable> aux;
name = string_compose ("%1 - monitor", name);
- list = session->new_audio_route (2, 2, 0, 1, name, PresentationInfo::ListenBus, (uint32_t) -1);
+ list = session->new_audio_route (2, 2, 0, 1, name, PresentationInfo::FoldbackBus, (uint32_t) -1);
aux = *(list.begin());
if (aux) {
boost::shared_ptr<Route> r = boost::dynamic_pointer_cast<Route>(aux);
@@ -4288,24 +4288,24 @@ OSC::sel_new_personal_send (char *listener, lo_message msg)
}
}
- /* if a listenbus called listener exists use it
- * other wise create create it. Then create a personal send from
+ /* if a foldbackbus called foldback exists use it
+ * other wise create create it. Then create a foldback send from
* this route to that bus.
*/